      subroutine tslz(a,x,r,m)
      integer m
      double complex a(1),x(m),r(1)
c
c     tslz calls tslz1 to solve the double complex linear system
c     a * x = b
c     with the t - matrix a .
c
c     on entry
c
c        a       double complex(2*m - 1)
c                the first row of the t - matrix followed by its
c                first column beginning with the second element .
c                on return a is unaltered .
c
c        x       double complex(m)
c                the right hand side vector b .
c
c        r       double complex(2*m - 2)
c                a work vector .
c
c        m       integer
c                the order of the matrix a .
c
c     on return
c
c        x       the solution vector .
c
c     toeplitz package. this version dated 07/23/82 .
c
c     subroutines and functions
c
c        toeplitz package ... tslz1
c
c     call subroutine tslz1
c
      call tslz1(a,a(m+1),x,x,r,r(m),m)
c
      return
      end